CloudCodeResult<T> class

Constructors

CloudCodeResult({required T? data, required int? statusCode, required String? requestId, required Map<String, String> headers})
const

Properties

data → T?
final
hashCode → int
The hash code for this object.
no setterinherited
headers → Map<String, String>
final
requestId → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
statusCode → int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited