DbStatement class

Properties

hashCode → int
The hash code for this object.
no setterinherited
params → List<Object?>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sql → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

of(String sql, [List<Object?>? params]) → DbStatement