MethodChannelAppAmbitSdkFlutter class

Inheritance

Properties

hashCode → int
The hash code for this object.
no setterinherited
methodChannel → MethodChannel
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addBreadcrumb(String name) → Future<void>
override
clearToken() → Future<void>
override
cloudCodeCall({required String correlationId, required String function, required String method, Map<String, String>? query, Map<String, dynamic>? body, Map<String, String>? headers}) → Future<Map>
Cloud Code
override
cloudCodeCancel(String correlationId) → Future<void>
override
dbBatch(List<Map<String, dynamic>> statements, {bool inTransaction = false}) → Future<List<Map>>
override
dbExecute(String sql, List<Object?>? params) → Future<Map>
Database
override
didCrashInLastSession() → Future<bool>
override
enable() → Future<bool>
Remote Config
override
enableManualSession() → Future<void>
override
endSession() → Future<void>
override
generateTestCrash() → Future<void>
override
generateTestEvent() → Future<void>
override
getBoolean(String key) → Future<bool>
override
getCmsList({required String contentType, required List<Map<String, dynamic>> filters, int? page, int? perPage, String? orderBy, String? orderDir}) → Future<List<Map<String, dynamic>>>
CMS
override
getDouble(String key) → Future<double>
override
getLong(String key) → Future<int>
override
getString(String key) → Future<String?>
override
logError(Map<String, dynamic>? payload) → Future<void>
override
logErrorMessage(Map<String, dynamic> payload) → Future<void>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setEmail(String email) → Future<void>
override
setUserId(String userId) → Future<void>
override
startCore({required String appKey}) → Future<void>
override
startSession() → Future<void>
override
toString() → String
A string representation of this object.
inherited
trackEvent(String name, Map<String, String> properties) → Future<void>
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited