CloudCode class

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

call(String function, {CloudCodeHttpMethod method = CloudCodeHttpMethod.post, Map<String, String>? query, Map<String, dynamic>? body, Map<String, String>? headers, Duration? timeout}) → CloudCodeRequest<CloudCodeResponse>
callTyped<T>(String function, {CloudCodeHttpMethod method = CloudCodeHttpMethod.post, Map<String, String>? query, Map<String, dynamic>? body, Map<String, String>? headers, Duration? timeout, required T fromJson(Object? value)}) → CloudCodeRequest<CloudCodeResult<T>>