CloudCodeError class
- Implemented types
Constructors
- CloudCodeError({required CloudCodeErrorCode code, required String message, String? function, String? header, int? statusCode, Object? body, String? rawBody, String? requestId})
-
const
- CloudCodeError.cancelled()
-
factory
- CloudCodeError.decoding(Object cause)
-
factory
- CloudCodeError.fromPlatformException(PlatformException error)
-
factory
- CloudCodeError.invalidBody(Object cause)
-
factory
- CloudCodeError.transport(Object cause)
-
factory
Properties
- body → Object?
-
final
- code → CloudCodeErrorCode
-
final
- function → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- header → String?
-
final
- message → String
-
final
- rawBody → String?
-
final
- requestId → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- statusCode → int?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited