AppAmbitCmsQuery<T> class

Constructors

AppAmbitCmsQuery(String _contentType, {required T fromJson(Map<String, dynamic>)})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

contains(String field, String value) AppAmbitCmsQuery<T>
equals(String field, String value) AppAmbitCmsQuery<T>
getList() Future<List<T>>
getPage(int page) AppAmbitCmsQuery<T>
getPerPage(int perPage) AppAmbitCmsQuery<T>
greaterThan(String field, num value) AppAmbitCmsQuery<T>
greaterThanOrEqual(String field, num value) AppAmbitCmsQuery<T>
inList(String field, List<String> values) AppAmbitCmsQuery<T>
lessThan(String field, num value) AppAmbitCmsQuery<T>
lessThanOrEqual(String field, num value) AppAmbitCmsQuery<T>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notEquals(String field, String value) AppAmbitCmsQuery<T>
notInList(String field, List<String> values) AppAmbitCmsQuery<T>
orderByAscending(String field) AppAmbitCmsQuery<T>
orderByDescending(String field) AppAmbitCmsQuery<T>
startsWith(String field, String value) AppAmbitCmsQuery<T>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited