DbQueryBuilder<T> class
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
count(
) → Future< int> -
delete(
) → Future< DbResult> -
first(
) → Future< T?> -
get(
) → Future< List< T> > -
insert(
Map< String, Object?> data) → Future<DbResult> -
limit(
int n) → DbQueryBuilder< T> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
offset(
int n) → DbQueryBuilder< T> -
orderBy(
String column) → DbQueryBuilder< T> -
orderByDesc(
String column) → DbQueryBuilder< T> -
select(
List< String> columns) → DbQueryBuilder<T> -
toString(
) → String -
A string representation of this object.
inherited
-
update(
Map< String, Object?> data) → Future<DbResult> -
where(
String column, Object? value) → DbQueryBuilder< T> -
whereIn(
String column, List< Object?> values) → DbQueryBuilder<T> -
whereOp(
String column, String op, Object? value) → DbQueryBuilder< T>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited