DbResult class

Constructors

DbResult({required List<String> columns, required List<List> rows, required int rowsRead, required int rowsWritten, String? error})
const
DbResult.fromMap(Map map)
factory

Properties

columns → List<String>
final
error → String?
final
hasError → bool
no setter
hashCode → int
The hash code for this object.
no setterinherited
rows → List<List>
final
rowsRead → int
final
rowsWritten → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
succeeded → bool
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMaps() → List<Map<String, dynamic>>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited