AppAmbitSdkFlutterPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • AppAmbitSdkFlutterPlatform
Implementers

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addBreadcrumb(String name) Future<void>
clearToken() Future<void>
didCrashInLastSession() Future<bool>
enable() Future<bool>
Remote Config
enableManualSession() Future<void>
endSession() Future<void>
generateTestCrash() Future<void>
generateTestEvent() Future<void>
getBoolean(String key) Future<bool>
getCmsList({required String contentType, required List<Map<String, dynamic>> filters, int? page, int? perPage, String? orderBy, String? orderDir}) Future<List<Map<String, dynamic>>>
CMS
getDouble(String key) Future<double>
getLong(String key) Future<int>
getString(String key) Future<String?>
logError(Map<String, dynamic>? payload) Future<void>
logErrorMessage(Map<String, dynamic> payload) Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setEmail(String email) Future<void>
setUserId(String userId) Future<void>
startCore({required String appKey}) Future<void>
startSession() Future<void>
toString() String
A string representation of this object.
inherited
trackEvent(String name, Map<String, String> properties) Future<void>

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance AppAmbitSdkFlutterPlatform
getter/setter pair